@@ -6,10 +6,10 @@ use Mojo::Promise;
 use Mojo::URL;
 use Mojo::UserAgent;
 
-use constant MOJO_JWT => !!(eval { require Mojo::JWT; require Crypt::OpenSSL::RSA; require Crypt::OpenSSL::Bignum; 1 });
+use constant MOJO_JWT => eval 'use Mojo::JWT 0.09; use Crypt::OpenSSL::RSA; use Crypt::OpenSSL::Bignum; 1';
 
 our @CARP_NOT = qw(Mojolicious::Plugin::OAuth2 Mojolicious::Renderer);
-our $VERSION = '2.00';
+our $VERSION = '2.01';
 
 has providers => sub {
   return {
